@@ -3,7 +3,7 @@
 # Business::Bitcoin::Request - Bitcoin payment request
 # Copyright (c) 2016-2017 Ashish Gulhati <biz-btc at hash dot neomailbox.ch>
 #
-# $Id: lib/Business/Bitcoin/Request.pm v1.028 Sun Jan 22 10:34:32 PST 2017 $
+# $Id: lib/Business/Bitcoin/Request.pm v1.029 Sat Feb  4 00:48:25 PST 2017 $
 
 use warnings;
 use strict;
@@ -21,7 +21,7 @@ use Crypt::RIPEMD160;
 
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.028 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.029 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my ($class, %args) = @_;
@@ -98,13 +98,13 @@ sub _address {
 
 sub _decompress {
   my $Kc = shift; $Kc =~ /^(..)(.*)/;
-  my $i = $1; my $K = '04' . $2; my $x = Math::BigInt->from_hex($2);
+  my $i = $1; my $K = '04' . '0' x (64 - length($2)) . $2; my $x = Math::BigInt->from_hex($2);
   my $curve = Math::EllipticCurve::Prime->from_name('secp256k1');
   my ($p, $a, $b) = ($curve->p, $curve->a, $curve->b);
   my $y = ($x->bmodpow(3,$p)+$a*$x+$b)->bmodpow(($p+1)/4,$p);
   $y = $p - $y if $i%2 ne $y%2;
   my $yhex = $y->as_hex; $yhex =~ s/^0x//;
-  $K .= $yhex;
+  $K .= '0' x (64 - length($yhex)) . $yhex;
   return $K;
 }
 
@@ -148,8 +148,8 @@ Business::Bitcoin::Request - Bitcoin payment request
 
 =head1 VERSION
 
- $Revision: 1.028 $
- $Date: Sun Jan 22 10:34:32 PST 2017 $
+ $Revision: 1.029 $
+ $Date: Sat Feb  4 00:48:25 PST 2017 $
 
 =head1 SYNOPSIS
 
